durationtools.Multiplier
========================

.. abjad-lineage:: abjad.tools.durationtools.Multiplier.Multiplier.Multiplier

.. autoclass:: abjad.tools.durationtools.Multiplier.Multiplier.Multiplier
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.durationtools.Multiplier.Multiplier.Multiplier.denominator
   :noindex:

.. autoattribute:: abjad.tools.durationtools.Multiplier.Multiplier.Multiplier.dot_count
   :noindex:

.. autoattribute:: abjad.tools.durationtools.Multiplier.Multiplier.Multiplier.equal_or_greater_assignable
   :noindex:

.. autoattribute:: abjad.tools.durationtools.Multiplier.Multiplier.Multiplier.equal_or_greater_power_of_two
   :noindex:

.. autoattribute:: abjad.tools.durationtools.Multiplier.Multiplier.Multiplier.equal_or_lesser_assignable
   :noindex:

.. autoattribute:: abjad.tools.durationtools.Multiplier.Multiplier.Multiplier.equal_or_lesser_power_of_two
   :noindex:

.. autoattribute:: abjad.tools.durationtools.Multiplier.Multiplier.Multiplier.flag_count
   :noindex:

.. autoattribute:: abjad.tools.durationtools.Multiplier.Multiplier.Multiplier.has_power_of_two_denominator
   :noindex:

.. autoattribute:: abjad.tools.durationtools.Multiplier.Multiplier.Multiplier.imag
   :noindex:

.. autoattribute:: abjad.tools.durationtools.Multiplier.Multiplier.Multiplier.implied_prolation
   :noindex:

.. autoattribute:: abjad.tools.durationtools.Multiplier.Multiplier.Multiplier.is_assignable
   :noindex:

.. autoattribute:: abjad.tools.durationtools.Multiplier.Multiplier.Multiplier.is_proper_tuplet_multiplier
   :noindex:

.. autoattribute:: abjad.tools.durationtools.Multiplier.Multiplier.Multiplier.lilypond_duration_string
   :noindex:

.. autoattribute:: abjad.tools.durationtools.Multiplier.Multiplier.Multiplier.numerator
   :noindex:

.. autoattribute:: abjad.tools.durationtools.Multiplier.Multiplier.Multiplier.pair
   :noindex:

.. autoattribute:: abjad.tools.durationtools.Multiplier.Multiplier.Multiplier.prolation_string
   :noindex:

.. autoattribute:: abjad.tools.durationtools.Multiplier.Multiplier.Multiplier.real
   :noindex:

.. autoattribute:: abjad.tools.durationtools.Multiplier.Multiplier.Multiplier.reciprocal
   :noindex:

.. autoattribute:: abjad.tools.durationtools.Multiplier.Multiplier.Multiplier.storage_format
   :noindex:

Methods
-------

.. automethod:: abjad.tools.durationtools.Multiplier.Multiplier.Multiplier.conjugate
   :noindex:

.. automethod:: abjad.tools.durationtools.Multiplier.Multiplier.Multiplier.from_decimal
   :noindex:

.. automethod:: abjad.tools.durationtools.Multiplier.Multiplier.Multiplier.from_float
   :noindex:

.. automethod:: abjad.tools.durationtools.Multiplier.Multiplier.Multiplier.limit_denominator
   :noindex:

.. automethod:: abjad.tools.durationtools.Multiplier.Multiplier.Multiplier.with_denominator
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.durationtools.Multiplier.Multiplier.Multiplier.__abs__
   :noindex:

.. automethod:: abjad.tools.durationtools.Multiplier.Multiplier.Multiplier.__add__
   :noindex:

.. automethod:: abjad.tools.durationtools.Multiplier.Multiplier.Multiplier.__complex__
   :noindex:

.. automethod:: abjad.tools.durationtools.Multiplier.Multiplier.Multiplier.__div__
   :noindex:

.. automethod:: abjad.tools.durationtools.Multiplier.Multiplier.Multiplier.__divmod__
   :noindex:

.. automethod:: abjad.tools.durationtools.Multiplier.Multiplier.Multiplier.__eq__
   :noindex:

.. automethod:: abjad.tools.durationtools.Multiplier.Multiplier.Multiplier.__float__
   :noindex:

.. automethod:: abjad.tools.durationtools.Multiplier.Multiplier.Multiplier.__floordiv__
   :noindex:

.. automethod:: abjad.tools.durationtools.Multiplier.Multiplier.Multiplier.__ge__
   :noindex:

.. automethod:: abjad.tools.durationtools.Multiplier.Multiplier.Multiplier.__gt__
   :noindex:

.. automethod:: abjad.tools.durationtools.Multiplier.Multiplier.Multiplier.__hash__
   :noindex:

.. automethod:: abjad.tools.durationtools.Multiplier.Multiplier.Multiplier.__le__
   :noindex:

.. automethod:: abjad.tools.durationtools.Multiplier.Multiplier.Multiplier.__lt__
   :noindex:

.. automethod:: abjad.tools.durationtools.Multiplier.Multiplier.Multiplier.__mod__
   :noindex:

.. automethod:: abjad.tools.durationtools.Multiplier.Multiplier.Multiplier.__mul__
   :noindex:

.. automethod:: abjad.tools.durationtools.Multiplier.Multiplier.Multiplier.__ne__
   :noindex:

.. automethod:: abjad.tools.durationtools.Multiplier.Multiplier.Multiplier.__neg__
   :noindex:

.. automethod:: abjad.tools.durationtools.Multiplier.Multiplier.Multiplier.__nonzero__
   :noindex:

.. automethod:: abjad.tools.durationtools.Multiplier.Multiplier.Multiplier.__pos__
   :noindex:

.. automethod:: abjad.tools.durationtools.Multiplier.Multiplier.Multiplier.__pow__
   :noindex:

.. automethod:: abjad.tools.durationtools.Multiplier.Multiplier.Multiplier.__radd__
   :noindex:

.. automethod:: abjad.tools.durationtools.Multiplier.Multiplier.Multiplier.__rdiv__
   :noindex:

.. automethod:: abjad.tools.durationtools.Multiplier.Multiplier.Multiplier.__rdivmod__
   :noindex:

.. automethod:: abjad.tools.durationtools.Multiplier.Multiplier.Multiplier.__repr__
   :noindex:

.. automethod:: abjad.tools.durationtools.Multiplier.Multiplier.Multiplier.__rfloordiv__
   :noindex:

.. automethod:: abjad.tools.durationtools.Multiplier.Multiplier.Multiplier.__rmod__
   :noindex:

.. automethod:: abjad.tools.durationtools.Multiplier.Multiplier.Multiplier.__rmul__
   :noindex:

.. automethod:: abjad.tools.durationtools.Multiplier.Multiplier.Multiplier.__rpow__
   :noindex:

.. automethod:: abjad.tools.durationtools.Multiplier.Multiplier.Multiplier.__rsub__
   :noindex:

.. automethod:: abjad.tools.durationtools.Multiplier.Multiplier.Multiplier.__rtruediv__
   :noindex:

.. automethod:: abjad.tools.durationtools.Multiplier.Multiplier.Multiplier.__str__
   :noindex:

.. automethod:: abjad.tools.durationtools.Multiplier.Multiplier.Multiplier.__sub__
   :noindex:

.. automethod:: abjad.tools.durationtools.Multiplier.Multiplier.Multiplier.__truediv__
   :noindex:

.. automethod:: abjad.tools.durationtools.Multiplier.Multiplier.Multiplier.__trunc__
   :noindex:
